@@ -5,5 +5,6 @@ Provides integration adapters for various frameworks.
 """
 
 from .langchain_adapter import LangChainAdapter
+from .openai_adapter import OpenAIAdapter
 
-__all__ = ['LangChainAdapter']
+__all__ = ['LangChainAdapter', 'OpenAIAdapter']
