@@ -20,13 +20,13 @@ from ..utils.async_sync_helper import get_global_helper
 # 旧的认证系统已被新的auth模块替代，保持向后兼容
 # from ..auth_security import get_auth_manager
 from ..cache_performance import get_performance_optimizer
-from ..component_control import get_component_manager
+from ..utils.component_control import get_component_manager
 from ..utils.exceptions import ServiceNotFoundError, InvalidConfigError, DeleteServiceError
 from ..monitoring import MonitoringManager, NetworkEndpoint, SystemResourceInfo
 from ..monitoring.analytics import get_monitoring_manager
 from ..integration.openapi_integration import get_openapi_manager
-from ..tool_transformation import get_transformation_manager
-from ..agent_service_mapper import AgentServiceMapper
+from .tool_transformation import get_transformation_manager
+from .agent_service_mapper import AgentServiceMapper
 
 # Create logger instance
 logger = logging.getLogger(__name__)
@@ -43,6 +43,7 @@ if TYPE_CHECKING:
 from .service_operations import ServiceOperationsMixin
 from .tool_operations import ToolOperationsMixin
 from .service_management import ServiceManagementMixin
+from .session_management import SessionManagementMixin
 from .advanced_features import AdvancedFeaturesMixin
 from .resources_prompts import ResourcesPromptsMixin
 from .agent_statistics import AgentStatisticsMixin
@@ -52,6 +53,7 @@ class MCPStoreContext(
     ServiceOperationsMixin,
     ToolOperationsMixin,
     ServiceManagementMixin,
+    SessionManagementMixin,
     AdvancedFeaturesMixin,
     ResourcesPromptsMixin,
     AgentStatisticsMixin
@@ -71,6 +73,9 @@ class MCPStoreContext(
         # 🔧 修复：初始化等待策略（来自ServiceOperationsMixin）
         from .service_operations import AddServiceWaitStrategy
         self.wait_strategy = AddServiceWaitStrategy()
+        
+        # 🆕 初始化会话管理（来自SessionManagementMixin）
+        SessionManagementMixin.__init__(self)
 
         # New feature manager
         self._transformation_manager = get_transformation_manager()
@@ -108,12 +113,55 @@ class MCPStoreContext(
         self._metadata: Dict[str, Any] = {}
         self._config: Dict[str, Any] = {}
         self._cache: Dict[str, Any] = {}
+        # Per-tool overrides (e.g., flags consumed by adapters like LangChain)
+        # Keyed by "{service_name}:{tool_name}" -> { flag_name: value }
+        self._tool_overrides: Dict[str, Dict[str, Any]] = {}
 
     def for_langchain(self) -> 'LangChainAdapter':
-        """Return a LangChain adapter instance for subsequent LangChain-related operations."""
-        from ...adapters.langchain_adapter import LangChainAdapter
+        """Return a LangChain adapter. If a session is active (within with_session),
+        return a session-aware adapter bound to that session; otherwise return the
+        standard context adapter.
+        """
+        # Avoid top-level import cycles
+        from ...adapters.langchain_adapter import LangChainAdapter, SessionAwareLangChainAdapter
+
+        active = getattr(self, "_active_session", None)
+        if active is not None and getattr(active, "is_active", False):
+            # Implicit session routing: with_session scope auto-binds LangChain tools
+            return SessionAwareLangChainAdapter(self, active)
+
         return LangChainAdapter(self)
-    
+
+    def for_llamaindex(self) -> 'LlamaIndexAdapter':
+        """Return a LlamaIndex adapter (FunctionTool) for MCP tools."""
+        from ...adapters.llamaindex_adapter import LlamaIndexAdapter
+        return LlamaIndexAdapter(self)
+
+    def for_crewai(self) -> 'CrewAIAdapter':
+        """Return a CrewAI adapter that reuses LangChain tools for compatibility."""
+        from ...adapters.crewai_adapter import CrewAIAdapter
+        return CrewAIAdapter(self)
+
+    def for_langgraph(self) -> 'LangGraphAdapter':
+        """Return a LangGraph adapter that reuses LangChain tools."""
+        from ...adapters.langgraph_adapter import LangGraphAdapter
+        return LangGraphAdapter(self)
+
+    def for_autogen(self) -> 'AutoGenAdapter':
+        """Return an AutoGen adapter that produces Python functions for registration."""
+        from ...adapters.autogen_adapter import AutoGenAdapter
+        return AutoGenAdapter(self)
+
+    def for_semantic_kernel(self) -> 'SemanticKernelAdapter':
+        """Return a Semantic Kernel adapter that produces native function callables."""
+        from ...adapters.semantic_kernel_adapter import SemanticKernelAdapter
+        return SemanticKernelAdapter(self)
+
+    def for_openai(self) -> 'OpenAIAdapter':
+        """Return an OpenAI adapter that produces OpenAI function calling format tools."""
+        from ...adapters.openai_adapter import OpenAIAdapter
+        return OpenAIAdapter(self)
+
     # === Hub 功能扩展 ===
     
     def hub_services(self) -> 'HubServicesBuilder':
@@ -159,103 +207,10 @@ class MCPStoreContext(
         return HubToolsBuilder(self, self._context_type.value, self._agent_id)
     
     # === 认证功能扩展 ===
+    # 注意：复杂的认证构建器已移除，现在使用简化的 auth/headers 参数方式
+    # 如需复杂认证配置，请直接使用 FastMCP 的原生API
     
-    def auth_jwt_payload(self, client_id: str) -> 'AuthTokenBuilder':
-        """
-        创建JWT Payload构建器
-        
-        用于生成FastMCP JWT token的payload配置。
-        FastMCP通过JWT token中的scopes和claims来管理用户权限。
-        
-        Args:
-            client_id: 客户端ID（用户ID）
-            
-        Returns:
-            AuthTokenBuilder: Token构建器，支持链式调用
-            
-        Example:
-            # 生成JWT payload
-            payload = store.for_store().auth_jwt_payload("user123")\\
-                .add_scopes("read", "write", "execute")\\
-                .add_claim("role", "admin")\\
-                .add_claim("tenant_id", "company_abc")\\
-                .generate_payload()
-        """
-        from ..auth.builder import AuthTokenBuilder
-        return AuthTokenBuilder(self, client_id)
-    
-    def auth_service(self, service_name: str) -> 'AuthServiceBuilder':
-        """
-        创建服务认证构建器
-        
-        配置服务的认证保护，生成FastMCP认证配置。
-        不实现实际认证逻辑，仅封装配置生成。
-        
-        Args:
-            service_name: 服务名称
-            
-        Returns:
-            AuthServiceBuilder: 服务认证构建器，支持链式调用
-            
-        Example:
-            # 保护服务
-            service_config = store.for_store().auth_service("payment-api")\\
-                .require_scopes("payment:read", "payment:write")\\
-                .set_access("admin")\\
-                .use_bearer_auth(
-                    jwks_uri="https://auth.company.com/.well-known/jwks.json",
-                    issuer="https://auth.company.com",
-                    audience="payment-service"
-                )\\
-                .protect()
-        """
-        from ..auth.builder import AuthServiceBuilder
-        return AuthServiceBuilder(self, service_name)
-    
-    def auth_provider(self, provider_type: str) -> 'AuthProviderBuilder':
-        """
-        创建认证提供者构建器
-        
-        配置认证提供者，生成FastMCP认证提供者配置。
-        支持bearer、oauth、google、github、workos等类型。
-        
-        Args:
-            provider_type: 认证提供者类型 (bearer, oauth, google, github, workos)
-            
-        Returns:
-            AuthProviderBuilder: 认证提供者构建器，支持链式调用
-            
-        Example:
-            # 配置Google OAuth
-            provider_config = store.for_store().auth_provider("google")\\
-                .set_client_credentials("google_client_id", "google_secret")\\
-                .set_base_url("https://myserver.com")\\
-                .setup()
-        """
-        from ..auth.builder import AuthProviderBuilder
-        return AuthProviderBuilder(self, provider_type)
-    
-    def auth_token(self, client_id: str) -> 'AuthTokenBuilder':
-        """
-        创建Token构建器（用于JWT payload生成）
-        
-        用于生成FastMCP JWT token的payload配置。
-        
-        Args:
-            client_id: 客户端ID
-            
-        Returns:
-            AuthTokenBuilder: Token构建器，支持链式调用
-            
-        Example:
-            # 生成JWT payload
-            payload = store.for_store().auth_token("user123")\\
-                .add_scopes("read", "write")\\
-                .add_claim("role", "admin")\\
-                .generate_payload()
-        """
-        from ..auth.builder import AuthTokenBuilder
-        return AuthTokenBuilder(self, client_id)
+    # TODO: 如果需要保留JWT相关功能，可以在后续版本中以更简单的方式实现
 
     def find_service(self, service_name: str) -> 'ServiceProxy':
         """
@@ -284,6 +239,35 @@ class MCPStoreContext(
         from .service_proxy import ServiceProxy
         return ServiceProxy(self, service_name)
 
+    def find_tool(self, tool_name: str) -> 'ToolProxy':
+        """
+        查找指定工具并返回工具代理对象
+        
+        在当前上下文范围内查找工具：
+        - Store 上下文: 搜索全局所有服务的工具
+        - Agent 上下文: 搜索该 Agent 的所有服务的工具
+        
+        Args:
+            tool_name: 工具名称
+            
+        Returns:
+            ToolProxy: 工具代理对象，包含该工具的所有操作方法
+            
+        Example:
+            # Store级别使用
+            weather_tool = store.for_store().find_tool('get_current_weather')
+            weather_tool.tool_info()        # 获取工具详情
+            weather_tool.call_tool({...})   # 调用工具
+            weather_tool.usage_stats()      # 使用统计
+            
+            # Agent级别使用
+            demo_tool = store.for_agent('demo1').find_tool('search_tool')
+            demo_tool.tool_info()           # 获取工具详情
+            demo_tool.test_call({...})      # 测试调用
+        """
+        from .tool_proxy import ToolProxy
+        return ToolProxy(self, tool_name, scope='context')
+
     @property
     def context_type(self) -> ContextType:
         """Get context type"""
@@ -338,6 +322,41 @@ class MCPStoreContext(
 
     # === Internal helper methods ===
     
+    def _tool_override_key(self, service_name: str, tool_name: str) -> str:
+        """Compose stable key for tool overrides."""
+        service_safe = service_name or ""
+        return f"{service_safe}:{tool_name}"
+
+    def _set_tool_override(self, service_name: str, tool_name: str, flag: str, value: Any) -> None:
+        """Set an override flag for a specific tool.
+
+        Args:
+            service_name: The service that provides the tool (agent-local or global depending on context view)
+            tool_name: Tool name as exposed by current context's tools view
+            flag: Override flag name, e.g., "return_direct"
+            value: Override value
+        """
+        try:
+            key = self._tool_override_key(service_name, tool_name)
+            if key not in self._tool_overrides:
+                self._tool_overrides[key] = {}
+            self._tool_overrides[key][flag] = value
+            logger.debug(f"[TOOL_OVERRIDE] set {flag}={value} for {key}")
+        except Exception as e:
+            logger.warning(f"[TOOL_OVERRIDE] failed to set override for {service_name}:{tool_name} flag={flag}: {e}")
+
+    def _get_tool_override(self, service_name: str, tool_name: str, flag: str, default: Any = None) -> Any:
+        """Get an override flag value for a tool, or default if not set."""
+        try:
+            key = self._tool_override_key(service_name, tool_name)
+            return self._tool_overrides.get(key, {}).get(flag, default)
+        except Exception:
+            return default
+
+    def _get_all_tool_overrides(self) -> Dict[str, Dict[str, Any]]:
+        """Return a snapshot of all tool overrides."""
+        return dict(self._tool_overrides)
+
     def _get_available_services(self) -> List[str]:
         """Get available service list"""
         try:
