@@ -13,6 +13,36 @@ from .types import ContextType
 
 logger = logging.getLogger(__name__)
 
+
+class UpdateServiceAuthHelper:
+    """更新服务认证助手 - 明确的服务名，避免状态混乱"""
+    
+    def __init__(self, context: 'MCPStoreContext', service_name: str, config: Dict[str, Any] = None):
+        self._context = context
+        self._service_name = service_name  # 🎯 明确的服务名，不会混乱
+        self._config = config.copy() if config else {}
+    
+    def bearer_auth(self, auth: str) -> 'MCPStoreContext':
+        """为指定服务更新 Bearer Token 认证"""
+        self._config["auth"] = auth
+        return self._execute_update()
+    
+    def custom_headers(self, headers: Dict[str, str]) -> 'MCPStoreContext':
+        """为指定服务更新自定义请求头"""
+        if "headers" not in self._config:
+            self._config["headers"] = {}
+        self._config["headers"].update(headers)
+        return self._execute_update()
+    
+    def _execute_update(self) -> 'MCPStoreContext':
+        """执行更新服务"""
+        self._context._sync_helper.run_async(
+            self._context.update_service_async(self._service_name, self._config),
+            timeout=60.0
+        )
+        return self._context
+
+
 class ServiceManagementMixin:
     """服务管理混入类"""
 
@@ -59,29 +89,60 @@ class ServiceManagementMixin:
             logger.info(f"[get_service_info] STORE模式-在global_agent_store中查找服务: {name}")
             return await self._store.get_service_info(name)
         elif self._context_type == ContextType.AGENT:
-            # Agent模式：将本地名称转换为全局名称进行查找
-            global_name = name
-            if self._service_mapper:
-                global_name = self._service_mapper.to_global_name(name)
-
-            logger.info(f"[get_service_info] AGENT模式-在agent({self._agent_id})中查找服务: {name} (global: {global_name})")
-            return await self._store.get_service_info(global_name, self._agent_id)
+            # Agent模式：将名称原样交给 Store 层处理，Store 负责本地名/全局名的鲁棒解析
+            logger.info(f"[get_service_info] AGENT模式-在agent({self._agent_id})中查找服务: {name}")
+            return await self._store.get_service_info(name, self._agent_id)
         else:
             logger.error(f"[get_service_info] 未知上下文类型: {self._context_type}")
             return {}
 
-    def update_service(self, name: str, config: Dict[str, Any]) -> bool:
+    def update_service(self, 
+                      name: str, 
+                      config: Union[Dict[str, Any], None] = None,
+                      # 🆕 与 FastMCP 对齐
+                      auth: Optional[str] = None,
+                      headers: Optional[Dict[str, str]] = None) -> Union['MCPStoreContext', 'UpdateServiceAuthHelper']:
         """
-        更新服务配置（同步版本）- 完全替换配置
-
+        更新服务配置，支持安全的链式认证
+        
         Args:
-            name: 服务名称
+            name: 服务名称（明确指定，不会混乱）
             config: 新的服务配置
-
+            auth: Bearer token，如果提供则立即执行
+            headers: 自定义请求头，如果提供则立即执行
+            
         Returns:
-            bool: 更新是否成功
+            如果有配置或认证参数：立即执行更新，返回 MCPStoreContext
+            如果什么都没有：返回 UpdateServiceAuthHelper 支持链式配置
         """
-        return self._sync_helper.run_async(self.update_service_async(name, config), timeout=60.0)
+        
+        if config is not None:
+            # 有配置参数：立即执行更新（保持向后兼容）
+            if auth is not None or headers is not None:
+                # 配置 + 认证：合并后执行
+                final_config = self._apply_auth_to_update_config(config, auth, headers)
+            else:
+                # 纯配置：直接执行
+                final_config = config
+                
+            self._sync_helper.run_async(
+                self.update_service_async(name, final_config),
+                timeout=60.0
+            )
+            return self
+        else:
+            # 没有配置参数：
+            if auth is not None or headers is not None:
+                # 纯认证：立即执行
+                final_config = self._apply_auth_to_update_config({}, auth, headers)
+                self._sync_helper.run_async(
+                    self.update_service_async(name, final_config),
+                    timeout=60.0
+                )
+                return self
+            else:
+                # 什么都没有：返回助手用于链式调用
+                return UpdateServiceAuthHelper(self, name, {})
 
     async def update_service_async(self, name: str, config: Dict[str, Any]) -> bool:
         """
@@ -131,11 +192,12 @@ class ServiceManagementMixin:
 
                 # 更新缓存中的 metadata.service_config，确保一致性
                 try:
-                    agent_key = self._agent_id
-                    metadata = self._store.registry.get_service_metadata(agent_key, global_name)
+                    # 将元数据更新到全局命名空间，保持与生命周期/工具缓存一致
+                    global_agent = self._store.client_manager.global_agent_store_id
+                    metadata = self._store.registry.get_service_metadata(global_agent, global_name)
                     if metadata:
                         metadata.service_config = config
-                        self._store.registry.set_service_metadata(agent_key, global_name, metadata)
+                        self._store.registry.set_service_metadata(global_agent, global_name, metadata)
                 except Exception as _:
                     pass
 
@@ -208,11 +270,12 @@ class ServiceManagementMixin:
 
                 # 更新缓存中的 metadata.service_config，确保一致性
                 try:
-                    agent_key = self._agent_id
-                    metadata = self._store.registry.get_service_metadata(agent_key, global_name)
+                    # 将元数据更新到全局命名空间，保持与生命周期/工具缓存一致
+                    global_agent = self._store.client_manager.global_agent_store_id
+                    metadata = self._store.registry.get_service_metadata(global_agent, global_name)
                     if metadata:
                         metadata.service_config.update(updates)
-                        self._store.registry.set_service_metadata(agent_key, global_name, metadata)
+                        self._store.registry.set_service_metadata(global_agent, global_name, metadata)
                 except Exception as _:
                     pass
 
@@ -342,7 +405,7 @@ class ServiceManagementMixin:
         """Store级别重置配置的内部实现"""
         try:
             if scope == "all":
-                logger.info("🔄 Store级别：重置所有缓存和所有JSON文件")
+                logger.info(" Store级别：重置所有缓存和所有JSON文件")
 
                 # 1. 清空所有缓存
                 self._store.registry.agent_clients.clear()
@@ -363,11 +426,11 @@ class ServiceManagementMixin:
                 # 3. 单源模式：不再维护分片映射文件
                 logger.info("Single-source mode: skip shard mapping files (agent_clients/client_services)")
 
-                logger.info("✅ Store级别：所有配置重置完成")
+                logger.info(" Store级别：所有配置重置完成")
                 return mcp_success
 
             elif scope == "global_agent_store":
-                logger.info("🔄 Store级别：只重置global_agent_store")
+                logger.info(" Store级别：只重置global_agent_store")
 
                 # 1. 清空global_agent_store在缓存中的数据
                 global_agent_store_id = self._store.client_manager.global_agent_store_id
@@ -380,7 +443,7 @@ class ServiceManagementMixin:
                 # 3. 单源模式：不再维护分片映射文件
                 logger.info("Single-source mode: skip shard mapping files (agent_clients/client_services)")
 
-                logger.info("✅ Store级别：global_agent_store重置完成")
+                logger.info(" Store级别：global_agent_store重置完成")
                 return mcp_success
 
             else:
@@ -394,7 +457,7 @@ class ServiceManagementMixin:
     async def _reset_agent_config(self) -> bool:
         """Agent级别重置配置的内部实现"""
         try:
-            logger.info(f"🔄 Agent级别：重置Agent {self._agent_id} 的所有配置")
+            logger.info(f" Agent级别：重置Agent {self._agent_id} 的所有配置")
 
             # 1. 清空Agent在缓存中的数据
             self._store.registry.clear(self._agent_id)
@@ -402,7 +465,7 @@ class ServiceManagementMixin:
             # 2. 单源模式：不再同步到分片文件
             logger.info("Single-source mode: skip shard mapping files sync")
 
-            logger.info(f"✅ Agent级别：Agent {self._agent_id} 配置重置完成")
+            logger.info(f" Agent级别：Agent {self._agent_id} 配置重置完成")
             return True
 
         except Exception as e:
@@ -456,7 +519,7 @@ class ServiceManagementMixin:
         """Store级别显示配置的内部实现"""
         try:
             if scope == "all":
-                logger.info("🔄 Store级别：显示所有Agent的配置")
+                logger.info(" Store级别：显示所有Agent的配置")
 
                 # 获取所有Agent ID
                 all_agent_ids = self._store.registry.get_all_agent_ids()
@@ -501,7 +564,7 @@ class ServiceManagementMixin:
                 }
 
             elif scope == "global_agent_store":
-                logger.info("🔄 Store级别：只显示global_agent_store的配置")
+                logger.info(" Store级别：只显示global_agent_store的配置")
 
                 global_agent_store_id = self._store.client_manager.global_agent_store_id
                 return await self._get_single_agent_config(global_agent_store_id)
@@ -525,7 +588,7 @@ class ServiceManagementMixin:
     async def _show_agent_config(self) -> Dict[str, Any]:
         """Agent级别显示配置的内部实现"""
         try:
-            logger.info(f"🔄 Agent级别：显示Agent {self._agent_id} 的配置")
+            logger.info(f" Agent级别：显示Agent {self._agent_id} 的配置")
 
             # 检查Agent是否存在
             all_agent_ids = self._store.registry.get_all_agent_ids()
@@ -679,14 +742,14 @@ class ServiceManagementMixin:
     def _is_deterministic_client_id(self, identifier: str) -> bool:
         """使用 ClientIDGenerator 统一判断确定性client_id格式"""
         try:
-            from mcpstore.core.id_generator import ClientIDGenerator
+            from mcpstore.core.utils.id_generator import ClientIDGenerator
             return ClientIDGenerator.is_deterministic_format(identifier)
         except Exception:
             return False
 
     def _parse_deterministic_client_id(self, client_id: str, agent_id: str) -> Tuple[str, str]:
         """使用 ClientIDGenerator 统一解析确定性client_id，并验证agent范围"""
-        from mcpstore.core.id_generator import ClientIDGenerator
+        from mcpstore.core.utils.id_generator import ClientIDGenerator
         parsed = ClientIDGenerator.parse_client_id(client_id)
         if parsed.get("type") == "store":
             global_agent_store_id = self._store.client_manager.global_agent_store_id
@@ -745,111 +808,63 @@ class ServiceManagementMixin:
         """
         logger.debug(f"[RESOLVE_CLIENT_ID] start value='{client_id_or_service_name}' agent='{agent_id}'")
 
-        # 🆕 优先级1: 智能格式识别（确定性client_id格式）
+        from .agent_service_mapper import AgentServiceMapper
+        global_agent_id = self._store.client_manager.global_agent_store_id
+
+        # 1) 优先：确定性 client_id 直接解析
         if self._is_deterministic_client_id(client_id_or_service_name):
             try:
                 client_id, service_name = self._parse_deterministic_client_id(client_id_or_service_name, agent_id)
                 logger.debug(f"[RESOLVE_CLIENT_ID] deterministic_ok client_id={client_id} service_name={service_name}")
-
-                # 验证解析结果的有效性
-                if self._validate_resolved_mapping(client_id, service_name, agent_id):
-                    return client_id, service_name
-                else:
-                    logger.warning(f"[RESOLVE_CLIENT_ID] deterministic_verify_failed")
+                return client_id, service_name
             except ValueError as e:
-                logger.debug(f"🔄 [RESOLVE_CLIENT_ID] 确定性格式解析失败: {e}")
+                logger.debug(f"[RESOLVE_CLIENT_ID] deterministic_parse_failed error={e}")
+                # 继续按服务名处理
 
-        # 🔄 优先级2: 作为client_id查找（支持所有格式）
-        try:
-            client_config = self._store.registry.get_client_config_from_cache(client_id_or_service_name)
-            if client_config and "mcpServers" in client_config:
-                # 验证这个client_id是否属于指定的agent（通过解析判断类型和agent范围）
-                from mcpstore.core.id_generator import ClientIDGenerator
-                parsed = ClientIDGenerator.parse_client_id(client_id_or_service_name)
-                if parsed.get("type") == "store":
-                    expected_agent = self._store.client_manager.global_agent_store_id
-                elif parsed.get("type") == "agent":
-                    expected_agent = parsed.get("agent_id")
-                else:
-                    expected_agent = None
-                if expected_agent == agent_id:
-                    # 找到对应的服务名
-                    service_names = list(client_config["mcpServers"].keys())
-                    if len(service_names) == 1:
-                        logger.debug(f"[RESOLVE_CLIENT_ID] client_id_lookup_ok value={client_id_or_service_name} service={service_names[0]}")
-                        return client_id_or_service_name, service_names[0]
-                    else:
-                        raise ValueError(f"Client {client_id_or_service_name} contains multiple services, which should not happen")
-        except Exception as e:
-            logger.debug(f"[RESOLVE_CLIENT_ID] client_id_lookup_failed error={e}")
-            pass  # 作为client_id查找失败，继续尝试作为服务名
+        # 2) Agent 模式：透明代理到 Store（不依赖 Agent 命名空间缓存）
+        if self._context_type == ContextType.AGENT and agent_id != global_agent_id:
+            # 2.1 判断输入是本地名还是全局名
+            input_name = client_id_or_service_name
+            global_service_name = None
 
-        # 优先级3: 作为服务名查找对应的client_id
-        try:
-            logger.debug(f"[RESOLVE_CLIENT_ID] try_as_service value='{client_id_or_service_name}'")
-
-            # 🔧 Agent 透明代理：处理服务名映射和查找
-            search_service_name = client_id_or_service_name
-
-            if self._context_type == ContextType.AGENT and agent_id != self._store.client_manager.global_agent_store_id:
-                # Agent 模式：支持多种查找方式（宽松匹配）
-                logger.debug(f"[RESOLVE_CLIENT_ID] agent_mode agent_id={agent_id}")
-
-                from mcpstore.core.agent_service_mapper import AgentServiceMapper
-
-                # 检查是否为全局服务名（带后缀）
-                if AgentServiceMapper.is_any_agent_service(client_id_or_service_name):
-                    try:
-                        parsed_agent_id, local_name = AgentServiceMapper.parse_agent_service_name(client_id_or_service_name)
-                        if parsed_agent_id == agent_id:
-                            # 是当前 Agent 的全局服务名，转换为本地名称
-                            search_service_name = local_name
-                            logger.debug(f"[RESOLVE_CLIENT_ID] global_to_local {client_id_or_service_name} -> {local_name}")
-                        else:
-                            raise ValueError(f"Service '{client_id_or_service_name}' belongs to agent '{parsed_agent_id}', not '{agent_id}'")
-                    except ValueError as e:
-                        raise ValueError(f"Invalid agent service name '{client_id_or_service_name}': {e}")
-                else:
-                    # 假设是本地服务名，直接使用
-                    search_service_name = client_id_or_service_name
-                    logger.debug(f"[RESOLVE_CLIENT_ID] use_local_service_name value={search_service_name}")
-
-            # 🔧 在指定agent范围内查找服务
-            service_names = self._store.registry.get_all_service_names(agent_id)
-            logger.debug(f"[RESOLVE_CLIENT_ID] agent_services agent='{agent_id}' services={service_names}")
-
-            # 🔍 查找服务并获取对应的client_id
-            if self._context_type == ContextType.AGENT and agent_id != self._store.client_manager.global_agent_store_id:
-                # Agent 模式：查找本地名称的服务
-                if search_service_name in service_names:
-                    client_id = self._store.registry.get_service_client_id(agent_id, search_service_name)
-                    if client_id:
-                        logger.debug(f"[RESOLVE_CLIENT_ID] agent_lookup_ok service={search_service_name} client_id={client_id}")
-                        return client_id, search_service_name
-                    else:
-                        raise ValueError(f"Service '{search_service_name}' found but no client_id mapping")
-                else:
-                    available_services = ', '.join(service_names) if service_names else 'None'
-                    raise ValueError(f"Service '{client_id_or_service_name}' not found in agent '{agent_id}'. Available services: {available_services}")
+            if AgentServiceMapper.is_any_agent_service(input_name):
+                # 输入是全局名，校验归属
+                try:
+                    parsed_agent_id, local_name = AgentServiceMapper.parse_agent_service_name(input_name)
+                    if parsed_agent_id != agent_id:
+                        raise ValueError(f"Service '{input_name}' belongs to agent '{parsed_agent_id}', not '{agent_id}'")
+                    global_service_name = input_name
+                except ValueError as e:
+                    raise ValueError(f"Invalid agent service name '{input_name}': {e}")
             else:
-                # Store 模式：直接查找
-                if search_service_name in service_names:
-                    client_id = self._store.registry.get_service_client_id(agent_id, search_service_name)
-                    if client_id:
-                        logger.debug(f"[RESOLVE_CLIENT_ID] store_lookup_ok service={search_service_name} client_id={client_id}")
-                        return client_id, search_service_name
-                    else:
-                        raise ValueError(f"Service '{search_service_name}' found but no client_id mapping")
-                else:
-                    available_services = ', '.join(service_names) if service_names else 'None'
-                    raise ValueError(f"Service '{client_id_or_service_name}' not found in store. Available services: {available_services}")
+                # 输入是本地名：优先用映射，其次用规则推导
+                mapped = self._store.registry.get_global_name_from_agent_service(agent_id, input_name)
+                global_service_name = mapped or AgentServiceMapper(agent_id).to_global_name(input_name)
 
-        except Exception as e:
-            logger.error(f"[RESOLVE_CLIENT_ID] error value='{client_id_or_service_name}' agent='{agent_id}' error={e}")
-            if "not found" in str(e) or "belongs to agent" in str(e) or "Invalid" in str(e):
-                raise e
+            # 2.2 在 Store 命名空间解析 client_id
+            client_id = self._store.registry.get_service_client_id(global_agent_id, global_service_name)
+            if not client_id:
+                available = ', '.join(self._store.registry.get_all_service_names(global_agent_id)) or 'None'
+                raise ValueError(
+                    f"Service '{input_name}' (global '{global_service_name}') not found in store. Available services: {available}"
+                )
+
+            logger.debug(f"[RESOLVE_CLIENT_ID] agent_proxy_ok local_or_global='{input_name}' -> global='{global_service_name}' client_id={client_id}")
+            return client_id, global_service_name
+
+        # 3) Store 模式：直接在 Store 命名空间解析
+        service_name = client_id_or_service_name
+        service_names = self._store.registry.get_all_service_names(agent_id)
+        if service_name in service_names:
+            client_id = self._store.registry.get_service_client_id(agent_id, service_name)
+            if client_id:
+                logger.debug(f"[RESOLVE_CLIENT_ID] store_lookup_ok service={service_name} client_id={client_id}")
+                return client_id, service_name
             else:
-                raise ValueError(f"Failed to resolve '{client_id_or_service_name}': {str(e)}")
+                raise ValueError(f"Service '{service_name}' found but no client_id mapping")
+
+        available_services = ', '.join(service_names) if service_names else 'None'
+        raise ValueError(f"Service '{service_name}' not found in store. Available services: {available_services}")
 
     async def _delete_store_config(self, client_id_or_service_name: str) -> Dict[str, Any]:
         """Store级别删除配置的内部实现"""
@@ -890,7 +905,7 @@ class ServiceManagementMixin:
             # 6. 单源模式：不再同步到分片文件
             logger.info("Single-source mode: skip shard mapping files sync")
 
-            logger.info(f"✅ Store级别：配置删除完成 {service_name}")
+            logger.info(f" Store级别：配置删除完成 {service_name}")
 
             return {
                 "success": True,
@@ -938,7 +953,7 @@ class ServiceManagementMixin:
             # 5. 单源模式：不再同步到分片文件
             logger.info("Single-source mode: skip shard mapping files sync")
 
-            logger.info(f"✅ Agent级别：配置删除完成 {service_name}")
+            logger.info(f" Agent级别：配置删除完成 {service_name}")
 
             return {
                 "success": True,
@@ -1015,14 +1030,14 @@ class ServiceManagementMixin:
     async def _update_store_config(self, client_id_or_service_name: str, new_config: Dict[str, Any]) -> Dict[str, Any]:
         """Store级别更新配置的内部实现"""
         try:
-            logger.info(f"🔄 Store级别：更新配置 {client_id_or_service_name}")
+            logger.info(f" Store级别：更新配置 {client_id_or_service_name}")
 
             global_agent_store_id = self._store.client_manager.global_agent_store_id
 
             # 解析client_id和服务名
             client_id, service_name = self._resolve_client_id(client_id_or_service_name, global_agent_store_id)
 
-            logger.info(f"🔄 解析结果: client_id={client_id}, service_name={service_name}")
+            logger.info(f" 解析结果: client_id={client_id}, service_name={service_name}")
 
             # 获取当前配置
             old_complete_info = self._store.registry.get_complete_service_info(global_agent_store_id, service_name)
@@ -1034,7 +1049,7 @@ class ServiceManagementMixin:
             # 验证和标准化新配置
             normalized_config = self._validate_and_normalize_config(new_config, service_name, old_config)
 
-            logger.info(f"🔄 配置验证通过，开始更新: {service_name}")
+            logger.info(f" 配置验证通过，开始更新: {service_name}")
 
             # 1. 清空服务的工具和会话数据
             self._store.registry.clear_service_tools_only(global_agent_store_id, service_name)
@@ -1073,7 +1088,7 @@ class ServiceManagementMixin:
                 global_agent_store_id, service_name, normalized_config
             )
 
-            logger.info(f"✅ Store级别：配置更新完成 {service_name}")
+            logger.info(f" Store级别：配置更新完成 {service_name}")
 
             return {
                 "success": True,
@@ -1098,12 +1113,12 @@ class ServiceManagementMixin:
     async def _update_agent_config(self, client_id_or_service_name: str, new_config: Dict[str, Any]) -> Dict[str, Any]:
         """Agent级别更新配置的内部实现"""
         try:
-            logger.info(f"🔄 Agent级别：更新Agent {self._agent_id} 的配置 {client_id_or_service_name}")
+            logger.info(f" Agent级别：更新Agent {self._agent_id} 的配置 {client_id_or_service_name}")
 
             # 解析client_id和服务名
             client_id, service_name = self._resolve_client_id(client_id_or_service_name, self._agent_id)
 
-            logger.info(f"🔄 解析结果: client_id={client_id}, service_name={service_name}")
+            logger.info(f" 解析结果: client_id={client_id}, service_name={service_name}")
 
             # 获取当前配置
             old_complete_info = self._store.registry.get_complete_service_info(self._agent_id, service_name)
@@ -1115,7 +1130,7 @@ class ServiceManagementMixin:
             # 验证和标准化新配置
             normalized_config = self._validate_and_normalize_config(new_config, service_name, old_config)
 
-            logger.info(f"🔄 配置验证通过，开始更新: {service_name}")
+            logger.info(f" 配置验证通过，开始更新: {service_name}")
 
             # 1. 清空服务的工具和会话数据
             self._store.registry.clear_service_tools_only(self._agent_id, service_name)
@@ -1147,7 +1162,7 @@ class ServiceManagementMixin:
                 self._agent_id, service_name, normalized_config
             )
 
-            logger.info(f"✅ Agent级别：配置更新完成 {service_name}")
+            logger.info(f" Agent级别：配置更新完成 {service_name}")
 
             return {
                 "success": True,
@@ -1183,7 +1198,8 @@ class ServiceManagementMixin:
                 global_name = name
                 if self._service_mapper:
                     global_name = self._service_mapper.to_global_name(name)
-                return self._store.orchestrator.get_service_status(global_name, self._agent_id)
+                # 透明代理：在全局命名空间查询状态
+                return self._store.orchestrator.get_service_status(global_name)
         except Exception as e:
             logger.error(f"Failed to get service status for {name}: {e}")
             return {"status": "error", "error": str(e)}
@@ -1198,9 +1214,10 @@ class ServiceManagementMixin:
             if self._context_type == ContextType.STORE:
                 return await self._store.orchestrator.restart_service(name)
             else:
-                # Agent模式：透明代理 - 将本地服务名映射到全局服务名
+                # Agent模式：透明代理 - 将本地服务名映射到全局服务名，并在全局命名空间执行重启
                 global_name = await self._map_agent_service_to_global(name)
-                return await self._store.orchestrator.restart_service(global_name, self._agent_id)
+                global_agent = self._store.client_manager.global_agent_store_id
+                return await self._store.orchestrator.restart_service(global_name, global_agent)
         except Exception as e:
             logger.error(f"Failed to restart service {name}: {e}")
             return False
@@ -1249,7 +1266,7 @@ class ServiceManagementMixin:
                 success = self._store.config.save_config(current_config)
 
                 if success:
-                    logger.info(f"✅ [SERVICE_DELETE] Store 服务删除成功: {service_name}")
+                    logger.info(f" [SERVICE_DELETE] Store 服务删除成功: {service_name}")
                 else:
                     logger.error(f"❌ [SERVICE_DELETE] Store 服务删除失败: {service_name}")
 
@@ -1292,7 +1309,7 @@ class ServiceManagementMixin:
                 success = self._store.config.save_config(current_config)
 
                 if success:
-                    logger.info(f"✅ [SERVICE_DELETE] Agent 服务删除成功: {local_name} → {global_name}")
+                    logger.info(f" [SERVICE_DELETE] Agent 服务删除成功: {local_name} → {global_name}")
                 else:
                     logger.error(f"❌ [SERVICE_DELETE] Agent 服务删除失败: {local_name} → {global_name}")
 
@@ -1384,15 +1401,18 @@ class ServiceManagementMixin:
         """
         try:
             # 解析参数
-            agent_id = self._agent_id if self._context_type == ContextType.AGENT else self._store.client_manager.global_agent_store_id
-            client_id, service_name = self._resolve_client_id(client_id_or_service_name, agent_id)
+            agent_scope = self._agent_id if self._context_type == ContextType.AGENT else self._store.client_manager.global_agent_store_id
+            client_id, service_name = self._resolve_client_id(client_id_or_service_name, agent_scope)
+
+            # 在纯视图模式下，Agent 的状态查询统一使用全局命名空间
+            status_agent_key = self._store.client_manager.global_agent_store_id
 
             # 解析等待模式
             change_mode = False
             if isinstance(status, str) and status.lower() == 'change':
                 change_mode = True
                 logger.info(f"[WAIT_SERVICE] start mode=change service='{service_name}' timeout={timeout}s")
-                initial_status = self._store.orchestrator.get_service_comprehensive_status(service_name, agent_id)
+                initial_status = self._store.orchestrator.get_service_comprehensive_status(service_name, status_agent_key)
             else:
                 # 规范化目标状态
                 target_statuses = self._normalize_target_statuses(status)
@@ -1418,7 +1438,7 @@ class ServiceManagementMixin:
 
                 # 获取当前状态
                 try:
-                    current_status = self._store.orchestrator.get_service_comprehensive_status(service_name, agent_id)
+                    current_status = self._store.orchestrator.get_service_comprehensive_status(service_name, status_agent_key)
 
                     # 仅在状态变化或每2秒节流一次打印
                     now = time.time()
@@ -1482,4 +1502,20 @@ class ServiceManagementMixin:
 
         return target_statuses
 
+    def _apply_auth_to_update_config(self, config: Dict[str, Any], 
+                                    auth: Optional[str], 
+                                    headers: Optional[Dict[str, str]]) -> Dict[str, Any]:
+        """将认证配置应用到更新配置中"""
+        final_config = config.copy() if config else {}
+        
+        if auth is not None:
+            final_config["auth"] = auth
+        
+        if headers is not None:
+            if "headers" not in final_config:
+                final_config["headers"] = {}
+            final_config["headers"].update(headers)
+        
+        return final_config
+
 
