@@ -129,6 +129,9 @@ class ServiceOperationsMixin:
                      json_file: str = None,
                      source: str = "manual",
                      wait: Union[str, int, float] = "auto",
+                     # 🆕 与 FastMCP 对齐的认证参数
+                     auth: Optional[str] = None,
+                     headers: Optional[Dict[str, str]] = None,
                      # 市场安装（同步封装）
                      from_market: str = None,
                      market_env: Dict[str, str] = None) -> 'MCPStoreContext':
@@ -142,12 +145,20 @@ class ServiceOperationsMixin:
             wait: 等待连接完成的时间
                 - "auto": 自动根据服务类型判断（远程2s，本地4s）
                 - 数字: 等待时间（毫秒）
+            auth: Bearer token（与 FastMCP 对齐）
+            headers: 自定义请求头（与 FastMCP 对齐）
             from_market: 市场服务名（与 config/json_file 互斥）
             market_env: 透传给市场配置的环境变量（不做本地校验）
+            
+        Returns:
+            MCPStoreContext: 上下文对象，保持一致性
         """
+        # 应用认证配置到服务配置中（如果提供了认证参数）
+        final_config = self._apply_auth_to_config(config, auth, headers)
+        
         # 🔧 修复：使用后台循环来支持后台任务
         return self._sync_helper.run_async(
-            self.add_service_async(config, json_file, source, wait, from_market=from_market, market_env=market_env),
+            self.add_service_async(final_config, json_file, source, wait, from_market=from_market, market_env=market_env),
             timeout=120.0,
             force_background=True  # 强制使用后台循环，确保后台任务不被取消
         )
@@ -332,6 +343,9 @@ class ServiceOperationsMixin:
                                json_file: str = None,
                                source: str = "manual",
                                wait: Union[str, int, float] = "auto",
+                               # 🆕 与 FastMCP 对齐的认证参数  
+                               auth: Optional[str] = None,
+                               headers: Optional[Dict[str, str]] = None,
                                # 新增市场功能参数
                                from_market: str = None,
                                market_env: Dict[str, str] = None) -> 'MCPStoreContext':
@@ -390,6 +404,9 @@ class ServiceOperationsMixin:
             MCPStoreContext: 返回自身实例以支持链式调用
         """
         try:
+            # === 新增：应用认证配置到服务配置中 ===
+            config = self._apply_auth_to_config(config, auth, headers)
+            
             # === 新增：处理市场安装参数 ===
             if from_market:
                 # 验证from_market参数
@@ -808,7 +825,7 @@ class ServiceOperationsMixin:
             global_agent_store_id=global_agent_store_id
         )
 
-        logger.debug(f"🆕 [CLIENT_ID] 生成新client_id: {service_name} -> {client_id}")
+        logger.debug(f" [CLIENT_ID] 生成新client_id: {service_name} -> {client_id}")
         return client_id
 
     async def _connect_and_update_cache(self, agent_id: str, service_name: str, service_config: Dict[str, Any]):
@@ -885,12 +902,12 @@ class ServiceOperationsMixin:
             logger.info("📁 Starting background file persistence...")
 
             if self._context_type == ContextType.STORE:
-                # Store模式：更新 mcp.json 和 agent_clients 映射
+                # 单一数据源模式：仅更新 mcp.json（agent_clients 映射仅更新缓存，不写分片文件）
                 await self._persist_to_mcp_json(services_to_add)
-                # 🔧 修复：Store模式也需要同步agent_clients映射到文件
+                # 单一数据源模式：跳过 agent_clients 分片文件的写入，仅维护缓存映射
                 await self._persist_store_agent_mappings(services_to_add)
             else:
-                # Agent模式：更新 agent_clients.json 和 client_services.json
+                # Agent模式：仅更新缓存，所有持久化仅通过 mcp.json 完成（分片文件已废弃）
                 await self._persist_to_agent_files(services_to_add)
 
             logger.info("📁 Background file persistence completed")
@@ -923,18 +940,18 @@ class ServiceOperationsMixin:
 
     async def _persist_store_agent_mappings(self, services_to_add: Dict[str, Dict[str, Any]]):
         """
-        Store模式：持久化agent_clients映射到文件
+        单一数据源模式：仅更新内存缓存中的 agent_clients 映射
 
-        Store模式下，服务添加到global_agent_store，需要同步映射关系到文件
+        说明：Store 模式下，服务添加到 global_agent_store，仅维护缓存映射；不再写入任何分片文件
         """
         try:
             agent_id = self._store.client_manager.global_agent_store_id
-            logger.info(f"🔄 Store模式agent映射持久化开始，agent_id: {agent_id}, 服务数量: {len(services_to_add)}")
-
-            # 单源模式：不再触发分片映射文件同步
-            logger.info("ℹ️ 单源模式：跳过 agent_clients 映射文件同步")
-
-            logger.info("✅ Store模式agent映射持久化完成")
+            # logger.info(f"🔄 Store模式agent映射持久化开始，agent_id: {agent_id}, 服务数量: {len(services_to_add)}")
+            #
+            # # 单源模式：不再触发分片映射文件同步
+            # logger.info("ℹ️ 单源模式：跳过 agent_clients 映射文件同步")
+            #
+            # logger.info("✅ Store模式agent映射持久化完成")
 
         except Exception as e:
             logger.error(f"Failed to persist store agent mappings: {e}")
@@ -978,7 +995,7 @@ class ServiceOperationsMixin:
             logger.error(f"Failed to persist to agent files with incremental cache update: {e}")
             raise
 
-    # === 🆕 Service Initialization Methods ===
+    # ===  Service Initialization Methods ===
 
     def init_service(self, client_id_or_service_name: str = None, *,
                      client_id: str = None, service_name: str = None) -> 'MCPStoreContext':
@@ -1161,7 +1178,7 @@ class ServiceOperationsMixin:
         try:
             logger.info(f"🔄 [AGENT_PROXY] 开始 Agent 透明代理添加服务，Agent: {agent_id}")
 
-            from mcpstore.core.agent_service_mapper import AgentServiceMapper
+            from .agent_service_mapper import AgentServiceMapper
             from mcpstore.core.models.service import ServiceConnectionState
 
             mapper = AgentServiceMapper(agent_id)
@@ -1257,14 +1274,11 @@ class ServiceOperationsMixin:
                 if (hasattr(self._store, 'orchestrator') and self._store.orchestrator and
                     hasattr(self._store.orchestrator, 'lifecycle_manager') and
                     self._store.orchestrator.lifecycle_manager):
-                    # 为两个缓存空间都初始化生命周期
+                    # 仅初始化全局命名空间的生命周期，避免对同一远端服务重复连接
                     self._store.orchestrator.lifecycle_manager.initialize_service(
                         self._store.client_manager.global_agent_store_id, global_name, service_config
                     )
-                    self._store.orchestrator.lifecycle_manager.initialize_service(
-                        agent_id, local_name, service_config
-                    )
-                    logger.debug(f"✅ [AGENT_PROXY] 初始化生命周期管理: {global_name}, {local_name}")
+                    logger.debug(f"✅ [AGENT_PROXY] 初始化生命周期管理(仅全局): {global_name}")
 
                 logger.info(f"✅ [AGENT_PROXY] Agent 服务添加完成: {local_name} → {global_name}")
 
@@ -1287,7 +1301,7 @@ class ServiceOperationsMixin:
             if "mcpServers" not in current_mcp_config:
                 current_mcp_config["mcpServers"] = {}
 
-            from mcpstore.core.agent_service_mapper import AgentServiceMapper
+            from .agent_service_mapper import AgentServiceMapper
             mapper = AgentServiceMapper(agent_id)
 
             for local_name, service_config in services_to_add.items():
@@ -1313,54 +1327,91 @@ class ServiceOperationsMixin:
         """
         获取 Agent 的服务视图（本地名称）
 
-        从 Agent 缓存中获取服务，转换为 ServiceInfo 对象，使用本地名称
+        透明代理（方案A）：不读取 Agent 命名空间缓存，
+        直接基于映射从 global_agent_store 的缓存派生服务列表。
         """
         try:
-            from mcpstore.core.models.service import ServiceInfo, TransportType
+            from mcpstore.core.models.service import ServiceInfo
+            from mcpstore.core.models.service import ServiceConnectionState
 
-            agent_services = []
+            agent_services: List[ServiceInfo] = []
+            agent_id = self._agent_id
+            global_agent_id = self._store.client_manager.global_agent_store_id
 
-            # 获取 Agent 缓存中的所有服务
-            if self._agent_id in self._store.registry.sessions:
-                agent_session_dict = self._store.registry.sessions[self._agent_id]
+            # 1) 通过映射获取该 Agent 的全局服务名集合
+            global_service_names = self._store.registry.get_agent_services(agent_id)
+            if not global_service_names:
+                logger.info(f"✅ [AGENT_VIEW] Agent {agent_id} 服务视图: 0 个服务（无映射）")
+                return agent_services
 
-                for local_name in agent_session_dict.keys():
-                    # 获取服务状态
-                    state = self._store.registry.get_service_state(self._agent_id, local_name)
+            # 2) 遍历每个全局服务，从全局命名空间读取完整信息，并以本地名展示
+            for global_name in global_service_names:
+                # 解析出 (agent_id, local_name)
+                mapping = self._store.registry.get_agent_service_from_global_name(global_name)
+                if not mapping:
+                    continue
+                mapped_agent, local_name = mapping
+                if mapped_agent != agent_id:
+                    continue
 
-                    # 获取 Client ID
-                    client_id = self._store.registry.get_service_client_id(self._agent_id, local_name)
+                complete_info = self._store.registry.get_complete_service_info(global_agent_id, global_name)
+                if not complete_info:
+                    logger.debug(f"[AGENT_VIEW] 全局缓存中未找到服务: {global_name}")
+                    continue
 
-                    # 获取服务配置
-                    service_config = {}
-                    if client_id and client_id in self._store.registry.client_configs:
-                        client_config = self._store.registry.client_configs[client_id]
-                        # 从 client 配置中提取对应的服务配置
-                        global_name = self._store.registry.get_global_name_from_agent_service(self._agent_id, local_name)
-                        if "mcpServers" in client_config:
-                            # 单源一致性：优先按本地名取配置，兼容性回退到全局名
-                            service_config = (
-                                client_config["mcpServers"].get(local_name)
-                                or (client_config["mcpServers"].get(global_name) if global_name else {})
-                                or {}
-                            )
+                # 状态转换
+                state = complete_info.get("state", ServiceConnectionState.DISCONNECTED)
+                if isinstance(state, str):
+                    try:
+                        state = ServiceConnectionState(state)
+                    except Exception:
+                        state = ServiceConnectionState.DISCONNECTED
 
-                    # 构造 ServiceInfo 对象
-                    service_info = ServiceInfo(
-                        name=local_name,  # 使用本地名称
-                        status=state.value if state else "unknown",
-                        transport_type=TransportType.STDIO,  # 默认传输类型
-                        client_id=client_id or "",
-                        config=service_config,
-                        tool_count=0,  # 暂时设为 0，后续可以实现工具计数
-                        keep_alive=False  # 默认值
-                    )
-                    agent_services.append(service_info)
-                    logger.debug(f"🔧 [AGENT_VIEW] 添加服务到视图: {local_name}")
+                cfg = complete_info.get("config", {})
+                tool_count = complete_info.get("tool_count", 0)
 
-            logger.info(f"✅ [AGENT_VIEW] Agent {self._agent_id} 服务视图: {len(agent_services)} 个服务")
+                # 透明代理：client_id 使用全局命名空间的 client_id
+                service_info = ServiceInfo(
+                    name=local_name,
+                    status=state,
+                    transport_type=self._store._infer_transport_type(cfg) if hasattr(self._store, '_infer_transport_type') else None,
+                    client_id=complete_info.get("client_id"),
+                    config=cfg,
+                    tool_count=tool_count,
+                    keep_alive=cfg.get("keep_alive", False),
+                )
+                agent_services.append(service_info)
+                logger.debug(f"🔧 [AGENT_VIEW] derive '{local_name}' <- '{global_name}' tools={tool_count}")
+
+            logger.info(f"✅ [AGENT_VIEW] Agent {agent_id} 服务视图: {len(agent_services)} 个服务（派生）")
             return agent_services
 
         except Exception as e:
             logger.error(f"❌ [AGENT_VIEW] 获取 Agent 服务视图失败: {e}")
             return []
+    
+    def _apply_auth_to_config(self, config, auth: Optional[str], headers: Optional[Dict[str, str]]):
+        """将认证配置应用到服务配置中"""
+        # 如果没有认证参数，直接返回原配置
+        if auth is None and headers is None:
+            return config
+        
+        # 处理不同类型的配置格式
+        if isinstance(config, dict):
+            final_config = config.copy()
+        elif config is None:
+            final_config = {}
+        else:
+            # 对于其他格式（如字符串），转换为字典
+            final_config = dict(config) if hasattr(config, '__iter__') and not isinstance(config, str) else {}
+        
+        # 应用认证配置
+        if auth is not None:
+            final_config["auth"] = auth
+        
+        if headers is not None:
+            if "headers" not in final_config:
+                final_config["headers"] = {}
+            final_config["headers"].update(headers)
+        
+        return final_config
