@@ -12,8 +12,6 @@ from mcpstore.core.models.service import JsonUpdateRequest
 
 from .api_decorators import handle_exceptions, get_store
 from .api_service_utils import (
-    reset_store_client_services, 
-    reset_store_agent_clients,
     ServiceOperationHelper
 )
 from .api_models import (
@@ -1395,19 +1393,7 @@ async def store_list_all_agents() -> APIResponse:
             data={"error": str(e)}
         )
 
-@store_router.post("/for_store/reset_client_services_file", response_model=APIResponse)
-@handle_exceptions
-async def store_reset_client_services_file() -> APIResponse:
-    """Store 级别重置 client_services 文件"""
-    store = get_store()
-    return await reset_store_client_services(store)
 
-@store_router.post("/for_store/reset_agent_clients_file", response_model=APIResponse)
-@handle_exceptions
-async def store_reset_agent_clients_file() -> APIResponse:
-    """Store 级别重置 agent_clients 文件"""
-    store = get_store()
-    return await reset_store_agent_clients(store)
 
 @store_router.get("/for_store/get_json_config", response_model=APIResponse)
 @handle_exceptions
